==> jc-1.4.0.tar.gz: java/nio/VMDirectByteBuffer.h <==
// final class java.nio.VMDirectByteBuffer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3daaac4d1a61d6b6 java_nio_VMDirectByteBuffer

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_nio_VMDirectByteBuffer_H_
#define _JC_java_nio_VMDirectByteBuffer_H_

// Forward structure declarations
struct _jc_gnu_classpath_RawData$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_nio_VMDirectByteBuffer$sub_refs	_jc_java_nio_VMDirectByteBuffer$sub_refs;
typedef struct _jc_java_nio_VMDirectByteBuffer$sub_nonrefs	_jc_java_nio_VMDirectByteBuffer$sub_nonrefs;
typedef struct _jc_java_nio_VMDirectByteBuffer$refs	_jc_java_nio_VMDirectByteBuffer$refs;
typedef struct _jc_java_nio_VMDirectByteBuffer$nonrefs	_jc_java_nio_VMDirectByteBuffer$nonrefs;
typedef struct _jc_java_nio_VMDirectByteBuffer$object	_jc_java_nio_VMDirectByteBuffer$object;

typedef const struct _jc_java_nio_VMDirectByteBuffer$vmethods	_jc_java_nio_VMDirectByteBuffer$vmethods;
typedef const struct _jc_java_nio_VMDirectByteBuffer$vtable	_jc_java_nio_VMDirectByteBuffer$vtable;
typedef const struct _jc_java_nio_VMDirectByteBuffer$vtype	_jc_java_nio_VMDirectByteBuffer$vtype;

// Constructors
extern void _jc_java_nio_VMDirectByteBuffer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_VMDirectByteBuffer$object *);

// Static methods
extern void _jc_java_nio_VMDirectByteBuffer$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_gnu_classpath_RawData$object *_jc_java_nio_VMDirectByteBuffer$method$adjustAddress$8bac725d2a157c00(_jc_env *, struct _jc_gnu_classpath_RawData$object *, jint);
extern struct _jc_gnu_classpath_RawData$object *_jc_java_nio_VMDirectByteBuffer$method$allocate$9849759d3dd0058a(_jc_env *, jint);
extern void _jc_java_nio_VMDirectByteBuffer$method$free$aed4c29a288bafa9(_jc_env *, struct _jc_gnu_classpath_RawData$object *);
extern jbyte _jc_java_nio_VMDirectByteBuffer$method$get$6750ad968ab7133c(_jc_env *, struct _jc_gnu_classpath_RawData$object *, jint);
extern void _jc_java_nio_VMDirectByteBuffer$method$get$57dec37ec104a373(_jc_env *, struct _jc_gnu_classpath_RawData$object *, jint, struct _jc_byte_array *, jint, jint);
extern void _jc_java_nio_VMDirectByteBuffer$method$init$d82f2cc8ccf1c754(_jc_env *);
extern void _jc_java_nio_VMDirectByteBuffer$method$put$b0c8cd5f29ae9ce2(_jc_env *, struct _jc_gnu_classpath_RawData$object *, jint, jbyte);
extern void _jc_java_nio_VMDirectByteBuffer$method$shiftDown$c346d34c3ecf60ab(_jc_env *, struct _jc_gnu_classpath_RawData$object *, jint, jint, jint);

// Virtual methods structure
struct _jc_java_nio_VMDirectByteBuffer$vmethods {
};

// Vtable
struct _jc_java_nio_VMDirectByteBuffer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_VMDirectByteBuffer$vmethods	java_nio_VMDirectByteBuffer;
};

// Vtype
struct _jc_java_nio_VMDirectByteBuffer$vtype {
	_jc_type			type;
	_jc_java_nio_VMDirectByteBuffer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_VMDirectByteBuffer$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_VMDirectByteBuffer$refs {
    _jc_java_nio_VMDirectByteBuffer$sub_refs	java_nio_VMDirectByteBuffer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_VMDirectByteBuffer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_VMDirectByteBuffer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_VMDirectByteBuffer$sub_nonrefs	java_nio_VMDirectByteBuffer;
};

// Object instance structure
struct _jc_java_nio_VMDirectByteBuffer$object {
	_jc_java_nio_VMDirectByteBuffer$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_VMDirectByteBuffer$vtype	*vtype;
	_jc_java_nio_VMDirectByteBuffer$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_VMDirectByteBuffer$vtype _jc_java_nio_VMDirectByteBuffer$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_VMDirectByteBuffer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_VMDirectByteBuffer$class_object;

#endif	/* _JC_java_nio_VMDirectByteBuffer_H_ */

==> jc-1.4.6.tar.gz: java/nio/VMDirectByteBuffer.h <==
// final class java.nio.VMDirectByteBuffer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3daaac4d1a61d6b6 java_nio_VMDirectByteBuffer

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_nio_VMDirectByteBuffer_H_
#define _JC_java_nio_VMDirectByteBuffer_H_

// Forward structure declarations
struct _jc_gnu_classpath_RawData$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_nio_VMDirectByteBuffer$sub_refs	_jc_java_nio_VMDirectByteBuffer$sub_refs;
typedef struct _jc_java_nio_VMDirectByteBuffer$sub_nonrefs	_jc_java_nio_VMDirectByteBuffer$sub_nonrefs;
typedef struct _jc_java_nio_VMDirectByteBuffer$refs	_jc_java_nio_VMDirectByteBuffer$refs;
typedef struct _jc_java_nio_VMDirectByteBuffer$nonrefs	_jc_java_nio_VMDirectByteBuffer$nonrefs;
typedef struct _jc_java_nio_VMDirectByteBuffer$object	_jc_java_nio_VMDirectByteBuffer$object;

typedef const struct _jc_java_nio_VMDirectByteBuffer$vmethods	_jc_java_nio_VMDirectByteBuffer$vmethods;
typedef const struct _jc_java_nio_VMDirectByteBuffer$vtable	_jc_java_nio_VMDirectByteBuffer$vtable;
typedef const struct _jc_java_nio_VMDirectByteBuffer$vtype	_jc_java_nio_VMDirectByteBuffer$vtype;

// Constructors
extern void _jc_java_nio_VMDirectByteBuffer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_VMDirectByteBuffer$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java_nio_VMDirectByteBuffer$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_gnu_classpath_RawData$object *_jc_java_nio_VMDirectByteBuffer$method$adjustAddress$8bac725d2a157c00(_jc_env *, struct _jc_gnu_classpath_RawData$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_gnu_classpath_RawData$object *_jc_java_nio_VMDirectByteBuffer$method$allocate$9849759d3dd0058a(_jc_env *, jint) _JC_JCNI_ATTR;
extern void _jc_java_nio_VMDirectByteBuffer$method$free$aed4c29a288bafa9(_jc_env *, struct _jc_gnu_classpath_RawData$object *) _JC_JCNI_ATTR;
extern jbyte _jc_java_nio_VMDirectByteBuffer$method$get$6750ad968ab7133c(_jc_env *, struct _jc_gnu_classpath_RawData$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_nio_VMDirectByteBuffer$method$get$57dec37ec104a373(_jc_env *, struct _jc_gnu_classpath_RawData$object *, jint, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_java_nio_VMDirectByteBuffer$method$init$d82f2cc8ccf1c754(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_java_nio_VMDirectByteBuffer$method$put$b0c8cd5f29ae9ce2(_jc_env *, struct _jc_gnu_classpath_RawData$object *, jint, jbyte) _JC_JCNI_ATTR;
extern void _jc_java_nio_VMDirectByteBuffer$method$shiftDown$c346d34c3ecf60ab(_jc_env *, struct _jc_gnu_classpath_RawData$object *, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_nio_VMDirectByteBuffer$vmethods {
};

// Vtable
struct _jc_java_nio_VMDirectByteBuffer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_VMDirectByteBuffer$vmethods	java_nio_VMDirectByteBuffer;
};

// Vtype
struct _jc_java_nio_VMDirectByteBuffer$vtype {
	_jc_type			type;
	_jc_java_nio_VMDirectByteBuffer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_VMDirectByteBuffer$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_VMDirectByteBuffer$refs {
    _jc_java_nio_VMDirectByteBuffer$sub_refs	java_nio_VMDirectByteBuffer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_VMDirectByteBuffer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_VMDirectByteBuffer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_VMDirectByteBuffer$sub_nonrefs	java_nio_VMDirectByteBuffer;
};

// Object instance structure
struct _jc_java_nio_VMDirectByteBuffer$object {
	_jc_java_nio_VMDirectByteBuffer$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_VMDirectByteBuffer$vtype	*vtype;
	_jc_java_nio_VMDirectByteBuffer$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_VMDirectByteBuffer$vtype _jc_java_nio_VMDirectByteBuffer$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_VMDirectByteBuffer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_VMDirectByteBuffer$class_object;

#endif	/* _JC_java_nio_VMDirectByteBuffer_H_ */
